==> huaweicloudsdkeihealth-3.1.138-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/task_instance_spec_containers_rsp.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TaskInstanceSpecContainersRsp:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resources': 'TaskInstanceSpecConResourceRsp'
    }

    attribute_map = {
        'resources': 'resources'
    }

    def __init__(self, resources=None):
        """TaskInstanceSpecContainersRsp

        The model defined in huaweicloud sdk

        :param resources: 
        :type resources: :class:`huaweicloudsdkeihealth.v1.TaskInstanceSpecConResourceRsp`
        """
        
        

        self._resources = None
        self.discriminator = None

        if resources is not None:
            self.resources = resources

    @property
    def resources(self):
        """Gets the resources of this TaskInstanceSpecContainersRsp.

        :return: The resources of this TaskInstanceSpecContainersRsp.
        :rtype: :class:`huaweicloudsdkeihealth.v1.TaskInstanceSpecConResourceRsp`
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this TaskInstanceSpecContainersRsp.

        :param resources: The resources of this TaskInstanceSpecContainersRsp.
        :type resources: :class:`huaweicloudsdkeihealth.v1.TaskInstanceSpecConResourceRsp`
        """
        self._resources = resources

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskInstanceSpecContainersRsp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeihealth-3.1.154-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/task_instance_spec_containers_rsp.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TaskInstanceSpecContainersRsp:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resources': 'TaskInstanceSpecConResourceRsp'
    }

    attribute_map = {
        'resources': 'resources'
    }

    def __init__(self, resources=None):
        r"""TaskInstanceSpecContainersRsp

        The model defined in huaweicloud sdk

        :param resources: 
        :type resources: :class:`huaweicloudsdkeihealth.v1.TaskInstanceSpecConResourceRsp`
        """
        
        

        self._resources = None
        self.discriminator = None

        if resources is not None:
            self.resources = resources

    @property
    def resources(self):
        r"""Gets the resources of this TaskInstanceSpecContainersRsp.

        :return: The resources of this TaskInstanceSpecContainersRsp.
        :rtype: :class:`huaweicloudsdkeihealth.v1.TaskInstanceSpecConResourceRsp`
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        r"""Sets the resources of this TaskInstanceSpecContainersRsp.

        :param resources: The resources of this TaskInstanceSpecContainersRsp.
        :type resources: :class:`huaweicloudsdkeihealth.v1.TaskInstanceSpecConResourceRsp`
        """
        self._resources = resources

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskInstanceSpecContainersRsp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
